<?php
/**
 * About Us Options
 *
 * @package Theme Palace
 * @subpackage Yummy Pro
 * @since Yummy Pro 1.0
 */

$wp_customize->add_panel( 'yummy_pro_about_us_template_panel' , array(
	    'title'      => esc_html__( 'About Us Template','yummy-pro' ),
	    'description'=> esc_html__( 'About Us Template Options.', 'yummy-pro' ),
	    'priority'   => 130,
) );

$wp_customize->add_section( 'yummy_pro_about_us_slider', array(
	'title'             => esc_html__( 'About Us Slider Section','yummy-pro' ),
	'panel'             => 'yummy_pro_about_us_template_panel',
) );

/**
 * Slider content type options.
 */
$wp_customize->add_setting( 'yummy_pro_theme_options[about_us_content_type]', array(
	'default'           => $options['about_us_content_type'],
	'sanitize_callback' => 'yummy_pro_sanitize_select',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[about_us_content_type]', array(
	'label'             => esc_html__( 'About Content Type', 'yummy-pro' ),
	'section'           => 'yummy_pro_about_us_slider',
	'choices'			=> yummy_pro_about_us_content_type_options(),
	'type'				=> 'select'
) );

// Nubmer of slider.
$wp_customize->add_setting( 'yummy_pro_theme_options[number_of_about_slider]', array(
	'default'           => $options['number_of_about_slider'],
	'sanitize_callback' => 'yummy_pro_sanitize_number_range',
	'validate_callback' => 'yummy_pro_validate_slider_count',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[number_of_about_slider]', array(
	'label'             => esc_html__( 'Number of sliders? ( Max: 5 )', 'yummy-pro' ),
	'active_callback' => 'yummy_pro_is_about_us_slider_content_type_post_disable',
	'description'       => esc_html__( 'Note: Please refresh after changing the value to see the changes.', 'yummy-pro' ),
	'section'           => 'yummy_pro_about_us_slider',
	'input_attrs'		=> array( 'min' => 1, 'max' => 5 ),
	'type'				=> 'number'
) );

// Post Options
$wp_customize->add_setting( 'yummy_pro_theme_options[about_us_slider_posts]', array(
	'sanitize_callback' => 'yummy_pro_sanitize_post_ids',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[about_us_slider_posts]', array(
	'label'           => esc_html__( 'Default Post IDs', 'yummy-pro' ),
	'active_callback' => 'yummy_pro_is_about_us_slider_content_type_post_enable',
	'description'     => esc_html__( 'Max. posts allowed is 5. ie: 11, 24, 34', 'yummy-pro' ),
	'section'         => 'yummy_pro_about_us_slider',
	'type'            => 'text',
) );

for ( $i=1; $i <= $options['number_of_about_slider']; $i++ ) { 
	/**
	 * Page Content Type Options
	 */
	// Page Options
	$wp_customize->add_setting( 'yummy_pro_theme_options[about_us_slider_page_'.$i.']', array(
		'sanitize_callback' => 'yummy_pro_sanitize_page'
	) );

	$wp_customize->add_control( 'yummy_pro_theme_options[about_us_slider_page_'.$i.']', array(
		'active_callback' => 'yummy_pro_is_about_us_slider_content_type_page_enable',
		'label'           => esc_html__( 'Select Page ', 'yummy-pro' ) . $i,
		'section'         => 'yummy_pro_about_us_slider',
		'type'            => 'dropdown-pages',
	) );
}

// Show category type setting and control
$wp_customize->add_setting( 'yummy_pro_theme_options[about_us_category_slider]', array(
	'sanitize_callback' => 'yummy_pro_sanitize_single_category'
) );

$wp_customize->add_control( new Yummy_Pro_Dropdown_Single_Category_Control( $wp_customize, 'yummy_pro_theme_options[about_us_category_slider]', array(
	'active_callback' => 'yummy_pro_is_about_us_slider_content_type_category_enable',
	'label'           => esc_html__( 'Select Category For About Us Slider', 'yummy-pro' ),
	'description'     => esc_html__( 'Only top post from selected category will be shown.', 'yummy-pro' ),
	'section'         => 'yummy_pro_about_us_slider',
) ) );

// Horizontal Line
$wp_customize->add_setting( 'yummy_pro_theme_options[basic_control]', array(
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( new Yummy_Pro_Customize_Horizontal_Line( $wp_customize, 'yummy_pro_theme_options[basic_control]',
	array(
		'section'         => 'yummy_pro_about_us_slider',
		'type'			  => 'hr',
) ) );

$wp_customize->add_setting( 'yummy_pro_theme_options[gallery_page_link]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[gallery_page_link]', array(
	'label'             => esc_html__( 'Gallery Link Button', 'yummy-pro' ),
	'description'		=> esc_html__( 'Enter the url if you want link button to be visible.','yummy-pro' ),
	'section'           => 'yummy_pro_about_us_slider',
	'type'				=> 'url'
) );

$wp_customize->add_setting( 'yummy_pro_theme_options[gallery_button_text]', array(
	'default'           => $options['gallery_button_text'],
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[gallery_button_text]', array(
	'label'             => esc_html__( 'Gallery Button Label', 'yummy-pro' ),
	'section'           => 'yummy_pro_about_us_slider',
	'type'				=> 'text'
) );

// About Us Our Team Section
$wp_customize->add_section( 'yummy_pro_our_team_slider', array(
	'title'             => esc_html__( 'Our Team Slider Section','yummy-pro' ),
	'panel'             => 'yummy_pro_about_us_template_panel',
) );

$wp_customize->add_setting( 'yummy_pro_theme_options[about_us_advert_content_type]', array(
	'default'           => $options['about_us_advert_content_type'],
	'sanitize_callback' => 'yummy_pro_sanitize_select',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[about_us_advert_content_type]', array(
	'label'             => esc_html__( 'Team Description Type', 'yummy-pro' ),
	'section'           => 'yummy_pro_our_team_slider',
	'choices'			=> yummy_pro_about_us_advert_content_type_options(),
	'type'				=> 'select',
	'priority'			=> 10,
) );

$wp_customize->add_setting( 'yummy_pro_theme_options[our_team_page_id]', array(
	'sanitize_callback' => 'yummy_pro_sanitize_page',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[our_team_page_id]', array(
	'label'             => esc_html__( 'Select Page', 'yummy-pro' ),
	'active_callback' => 'yummy_pro_is_about_us_team_advert_type_page_enable',
	'section'           => 'yummy_pro_our_team_slider',
	'type'				=> 'dropdown-pages',
	'priority'			=> 10,
) );

$wp_customize->add_setting( 'yummy_pro_theme_options[our_team_post_id]', array(
	'sanitize_callback' => 'yummy_pro_sanitize_number_range',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[our_team_post_id]', array(
	'label'             => esc_html__( 'Input Post ID', 'yummy-pro' ),
	'active_callback' => 'yummy_pro_is_about_us_team_advert_type_post_enable',
	'section'           => 'yummy_pro_our_team_slider',
	'type'				=> 'number',
	'priority'			=> 11,
	'input_attrs'	  	=> array( 
		'min'			=> 1,
		'style'			=> 'width:100px' 
	),
) );

// Horizontal Line
$wp_customize->add_setting( 'yummy_pro_theme_options[advert_basic_controls]', array(
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( new Yummy_Pro_Customize_Horizontal_Line( $wp_customize, 'yummy_pro_theme_options[advert_basic_controls]',
	array(
		'section'         => 'yummy_pro_our_team_slider',
		'type'			  => 'hr',
		'priority'		  => 11,
) ) );

$wp_customize->add_setting( 'yummy_pro_theme_options[about_us_team_content_type]', array(
	'default'           => $options['about_us_team_content_type'],
	'sanitize_callback' => 'yummy_pro_sanitize_select',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[about_us_team_content_type]', array(
	'label'             => esc_html__( 'Team Member Type', 'yummy-pro' ),
	'section'           => 'yummy_pro_our_team_slider',
	'choices'			=> yummy_pro_about_us_team_content_type_options(),
	'type'				=> 'select',
	'priority'			=> 12,
) );

/**
 * Post Content Type Options
 */
// Post Options
$wp_customize->add_setting( 'yummy_pro_theme_options[our_team_slider_posts]', array(
	'sanitize_callback' => 'yummy_pro_sanitize_post_ids',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[our_team_slider_posts]', array(
	'label'           => esc_html__( 'Default Post IDs', 'yummy-pro' ),
	'active_callback' => 'yummy_pro_is_about_us_team_content_type_post_enable',
	'description'     => esc_html__( 'Max. posts allowed is 5. ie: 11, 24, 34', 'yummy-pro' ),
	'section'         => 'yummy_pro_our_team_slider',
	'type'            => 'text',
	'priority'			=> 13,
) );

// Horizontal Line
$wp_customize->add_setting( 'yummy_pro_theme_options[choice_basic_controls]', array(
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( new Yummy_Pro_Customize_Horizontal_Line( $wp_customize, 'yummy_pro_theme_options[choice_basic_controls]',
	array(
		'section'         => 'yummy_pro_our_team_slider',
		'type'			  => 'hr',
		'priority'		  => 15,
) ) );

if( class_exists( 'TP_Philosophy_Tools' ) ) { 
	/**
	 * Post Content Type Options
	 */
	// Post Options
	$wp_customize->add_setting( 'yummy_pro_theme_options[our_team_slider_tp_posts]', array(
		'sanitize_callback' => 'yummy_pro_sanitize_post_ids',
	) );

	$wp_customize->add_control( 'yummy_pro_theme_options[our_team_slider_tp_posts]', array(
		'label'           => esc_html__( 'Team Post IDs', 'yummy-pro' ),
		'active_callback' => 'yummy_pro_is_about_us_team_content_type_tp_post_enable',
		'description'     => esc_html__( 'Max. posts allowed is 5. ie: 11, 24, 34', 'yummy-pro' ),
		'section'         => 'yummy_pro_our_team_slider',
		'type'            => 'text',
		'priority'			=> 14,
	) );
}

$wp_customize->add_setting( 'yummy_pro_theme_options[about_us_choice_content_type]', array(
	'default'           => $options['about_us_choice_content_type'],
	'sanitize_callback' => 'yummy_pro_sanitize_select',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[about_us_choice_content_type]', array(
	'label'             => esc_html__( 'Teams Preferred Menu Type', 'yummy-pro' ),
	'section'           => 'yummy_pro_our_team_slider',
	'choices'			=> yummy_pro_about_us_choice_content_type_options(),
	'type'				=> 'select',
	'priority'			=> 15,
) );

// Show category type setting and control
$wp_customize->add_setting( 'yummy_pro_theme_options[team_content_category]', array(
	'sanitize_callback' => 'yummy_pro_sanitize_single_category',
) );

$wp_customize->add_control( new Yummy_Pro_Dropdown_Single_Category_Control( $wp_customize, 'yummy_pro_theme_options[team_content_category]', array(
	'label'           => esc_html__( 'Select Category', 'yummy-pro' ),
	'description'     => esc_html__( 'Latest posts from selected category will be shown.', 'yummy-pro' ),
	'section'         => 'yummy_pro_our_team_slider',
	'type'			  => 'dropdown-category',
	'active_callback' => 'yummy_pro_is_team_content_category_enable',
	'priority'			=> 16,
) ) );

if( class_exists( 'WooCommerce' ) ) { 
	// Show category type setting and control
	$wp_customize->add_setting( 'yummy_pro_theme_options[team_content_woo_category]', array(
		'sanitize_callback' => 'absint',
	) );

	$wp_customize->add_control( new Yummy_Pro_Dropdown_Single_Category_Control( $wp_customize, 'yummy_pro_theme_options[team_content_woo_category]', array(
		'label'           => esc_html__( 'Select Woo Product Category', 'yummy-pro' ),
		'description'     => esc_html__( 'Latest posts from selected category will be shown.', 'yummy-pro' ),
		'section'         => 'yummy_pro_our_team_slider',
		'taxonomy'		  => 'product_cat',
		'type'			  => 'dropdown-category',
		'active_callback' => 'yummy_pro_is_team_content_woo_category_enable',
		'priority'			=> 17,
	) ) );
}

//About Us Interior Decoration Section
$wp_customize->add_section( 'yummy_pro_about_us_interior', array(
	'title'             => esc_html__( 'Interior Section','yummy-pro' ),
	'panel'             => 'yummy_pro_about_us_template_panel',
) );


$wp_customize->add_setting( 'yummy_pro_theme_options[interior_decoration_title]', array(
	'default'           => $options['interior_decoration_title'],
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[interior_decoration_title]', array(
	'label'             => esc_html__( 'Interior Section Title', 'yummy-pro' ),
	'section'           => 'yummy_pro_about_us_interior',
	'type'				=> 'text'
) );

$wp_customize->add_setting( 'yummy_pro_theme_options[interior_decoration_subtitle]', array(
	'default'           => $options['interior_decoration_subtitle'],
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[interior_decoration_subtitle]', array(
	'label'             => esc_html__( 'Interior Section Subtitle', 'yummy-pro' ),
	'section'           => 'yummy_pro_about_us_interior',
	'type'				=> 'text'
) );

$wp_customize->add_setting( 'yummy_pro_theme_options[about_us_interior_content_type]', array(
	'default'           => $options['about_us_interior_content_type'],
	'sanitize_callback' => 'yummy_pro_sanitize_select',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[about_us_interior_content_type]', array(
	'label'             => esc_html__( 'Interior Content Type', 'yummy-pro' ),
	'section'           => 'yummy_pro_about_us_interior',
	'choices'			=> yummy_pro_about_us_interior_content_type_options(),
	'type'				=> 'select'
) );

// Horizontal Line
$wp_customize->add_setting( 'yummy_pro_theme_options[basic_controls]', array(
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( new Yummy_Pro_Customize_Horizontal_Line( $wp_customize, 'yummy_pro_theme_options[basic_controls]',
	array(
		'section'         => 'yummy_pro_about_us_interior',
		'type'			  => 'hr',
) ) );

for ( $i=1; $i <= 4; $i++ ) { 
	/**
	 * Page Content Type Options
	 */
	$wp_customize->add_setting( 'yummy_pro_theme_options[interior_category_title_'.$i.']', array(
		'default'           => $options['interior_category_title'],
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'yummy_pro_theme_options[interior_category_title_'.$i.']', array(
		'label'             => esc_html__( 'Interior Category Title', 'yummy-pro' ) . $i,
		'description'	    => esc_html__( 'This Title represents the category of the gallery and will be same for all content types.','yummy-pro' ),
		'section'           => 'yummy_pro_about_us_interior',
		'type'				=> 'text'
	) );
	// Page Options
	$wp_customize->add_setting( 'yummy_pro_theme_options[about_us_interior_page_'.$i.']', array(
		'sanitize_callback' => 'yummy_pro_sanitize_page'
	) );

	$wp_customize->add_control( 'yummy_pro_theme_options[about_us_interior_page_'.$i.']', array(
		'active_callback' => 'yummy_pro_is_about_us_interior_content_type_page_enable',
		'label'           => esc_html__( 'Select Page ', 'yummy-pro' ) . $i,
		'description'	  => esc_html__( 'Select the page in which the gallery template is set.','yummy-pro' ),

		'section'         => 'yummy_pro_about_us_interior',
		'type'            => 'dropdown-pages',
	) );

	/**
	 * Post Content Type Options
	 */
	// Post Options
	$wp_customize->add_setting( 'yummy_pro_theme_options[about_us_interior_post_'.$i.']', array(
		'sanitize_callback' => 'yummy_pro_sanitize_number_range',
		'validate_callback' => 'yummy_pro_validate_post_id',
	) );

	$wp_customize->add_control( 'yummy_pro_theme_options[about_us_interior_post_'.$i.']', array(
		'active_callback' => 'yummy_pro_is_about_us_interior_content_type_post_enable',
		'label'           => sprintf( esc_html__( 'Post ID %d', 'yummy-pro' ) , $i ),
		'description'	  => esc_html__( 'Select the post in which the gallery template is set.','yummy-pro' ),
		'section'         => 'yummy_pro_about_us_interior',
		'type'            => 'number',
		'input_attrs'	  => array( 
			'min'			=> 1,
			'style'			=> 'width:100px' 
		),
	) );

	$wp_customize->add_setting( 'yummy_pro_theme_options[interior_custom_title_'.$i.']', array(
		'default'           => $options['interior_custom_title'],
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'yummy_pro_theme_options[interior_custom_title_'.$i.']', array(
		'active_callback'  	=> 'yummy_pro_is_about_us_interior_content_type_custom_enable',
		'label'             => esc_html__( 'Custom Title', 'yummy-pro' ) . $i,
		'section'           => 'yummy_pro_about_us_interior',
		'type'				=> 'text'
	) );

	// Image Options
	$wp_customize->add_setting( 'yummy_pro_theme_options[interior_custom_image_'.$i.']', array(
		'sanitize_callback' => 'yummy_pro_sanitize_image',
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control(  $wp_customize, 'yummy_pro_theme_options[interior_custom_image_'.$i.']', array(
		'active_callback' => 'yummy_pro_is_about_us_interior_content_type_custom_enable',
		'label'           => esc_html__( 'Custom Image', 'yummy-pro' ),
		'description'	  => esc_html__( 'Preferred size is 700px by 550px','yummy-pro' ),
		'section'         => 'yummy_pro_about_us_interior',	
	) ) );

	$wp_customize->add_setting( 'yummy_pro_theme_options[interior_gallery_button_text_'.$i.']', array(
	'default'           	=> $options['gallery_button_text'],
	'sanitize_callback' 	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'yummy_pro_theme_options[interior_gallery_button_text_'.$i.']', array(
		'label'             => esc_html__( 'Gallery Button Label', 'yummy-pro' ) .$i,
		'description'		=> esc_html__( 'This label is used for gallery link button and will be same for all content types.','yummy-pro' ),
		'section'           => 'yummy_pro_about_us_interior',
		'type'				=> 'text'
	) );

	$wp_customize->add_setting( 'yummy_pro_theme_options[interior_gallery_page_link_'.$i.']', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( 'yummy_pro_theme_options[interior_gallery_page_link_'.$i.']', array(
		'active_callback'  	=> 'yummy_pro_is_about_us_interior_content_type_custom_enable',
		'label'             => esc_html__( 'Custom Gallery Link Button', 'yummy-pro' ) .$i,
		'section'           => 'yummy_pro_about_us_interior',
		'type'				=> 'url'
	) );

	// Horizontal Line
	$wp_customize->add_setting( 'yummy_pro_theme_options[basic_controls_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Yummy_Pro_Customize_Horizontal_Line( $wp_customize, 'yummy_pro_theme_options[basic_controls_'.$i.']',
		array(
			'section'         => 'yummy_pro_about_us_interior',
			'type'			  => 'hr',
	) ) );
}