<?php
/**
 * Opening Hours Widget
 *
 * @package Theme Palace
 * @subpackage Yummy Pro
 * @since Yummy Pro 1.0
 */

if ( ! class_exists( 'Yummy_Pro_Custom_Openning_Hours_Widget' ) ) :
	/**
	 * Opening Hours class.
	 *
	 * @since yummy Pro 1.0
	 */
	class Yummy_Pro_Custom_Openning_Hours_Widget extends WP_Widget {
		/**
		 * Sets up the widgets name etc
		 */
		public function __construct() {
			$widget_ops = array(
				'classname'   => 'tp_openning_hours',
				'description' => esc_html__( 'Retrieves latest scheduling rule.', 'yummy-pro' ),
			);
			parent::__construct( 'tp_openning_hours',esc_html__( 'TP : Opening Hours','yummy-pro' ), $widget_ops );
		}

		/**
		 * Outputs the content of the widget
		 *
		 * @param array $args
		 * @param array $instance
		 */
		public function widget( $args, $instance ) { 
			if ( ! isset( $args['widget_id'] ) ) {
				$args['widget_id'] = $this->id;
			}

			$title 	= ( ! empty( $instance['title'] ) ) ? $instance['title'] : esc_html__( 'Opening Hours', 'yummy-pro' );

			echo $args['before_widget'];
				if ( ! empty( $title ) ) {
					echo $args['before_title'] . esc_html( $title ) . $args['after_title'];
				}

			$rtb_setting 	 = get_option('rtb-settings');
			if( empty( $rtb_setting ) ){
				return;
			}
			$schedules_open  = $rtb_setting['schedule-open'];
			$schedules_close = $rtb_setting['schedule-closed'];

			foreach( $schedules_close as $key => $schedule_close ) {
				$date = $schedule_close['date'];
			}
			foreach( $schedules_open as $key => $schedule_open ) {
				$weekdays = $schedule_open['weekdays'];
				$times 	  = $schedule_open['time'];
			?>
	            <ul>
	              	<?php foreach( $weekdays as $key => $weekday ){ ?>
	              		<li>
	                    	<span class="opening-day"><?php echo esc_html( $key ); ?></span>
	                    	<span class="opening-time">
		                    	<?php 
		                    	if ( ! empty( $times['start'] ) ) {
		                    		echo $times['start'];
		                    	} 
		                    	echo ' - ';
		                    	if ( ! empty( $times['end'] ) ) {
		                    		echo $times['end'];
		                    	} ?>
		                    </span>						
	                  	</li>
					<?php } ?>
				</ul> 
			<?php }
			if( !empty( $date ) ) { ?>
          	<ul>
          		<li class="closed">
            		<span class="opening-day"><?php esc_html_e( 'Will Be Closed On','yummy-pro' ); ?></span>
            		<span class="opening-time"><?php echo esc_html( $date ); ?></span>
          		</li>
            </ul>
          	<?php } 	
			echo $args['after_widget']; 
		}

		/**
		 * Outputs the options form on admin
		 *
		 * @param array $instance The widget options
		 */
		public function form( $instance ) {
			$title     	= isset( $instance['title'] ) ? ( $instance['title'] ) : esc_html__( 'Opening Hours', 'yummy-pro' );
		   	?>

		   	<p>
			   	<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title:', 'yummy-pro' ); ?></label>
			   	<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
		   	</p>
		<?php }

		/**
		* Processing widget options on save
		*
		* @param array $new_instance The new options
		* @param array $old_instance The previous options
		*/
		public function update( $new_instance, $old_instance ) {
			// processes widget options to be saved
			$instance           			= $old_instance;
			$instance['title']  			= sanitize_text_field( $new_instance['title'] );
			return $instance;
		}
	}
endif;

function yummy_pro_register_opening_hours_widget() {
	register_widget( 'Yummy_Pro_Custom_Openning_Hours_Widget' );
}
add_action( 'widgets_init', 'yummy_pro_register_opening_hours_widget' );