<?php
/**
 * Reservation Widget
 *
 * @package Theme Palace
 * @subpackage Yummy Pro
 * @since Yummy Pro 1.0
 */

if ( ! class_exists( 'Yummy_Pro_Custom_Reservation_Widget' ) ) :
	/**
	 * Reservation class.
	 *
	 * @since yummy Pro 1.0
	 */
	class Yummy_Pro_Custom_Reservation_Widget extends WP_Widget {
		/**
		 * Sets up the widgets name etc
		 */
		public function __construct() {
			$widget_ops = array(
				'classname'   => 'tp_reservation',
				'description' => esc_html__( 'Enter the url in the button.', 'yummy-pro' ),
			);
			parent::__construct( 'tp_reservation',esc_html__( 'TP : Reservation','yummy-pro' ), $widget_ops );
		}

		/**
		 * Outputs the content of the widget
		 *
		 * @param array $args
		 * @param array $instance
		 */
		public function widget( $args, $instance ) { 
			if ( ! isset( $args['widget_id'] ) ) {
				$args['widget_id'] = $this->id;
			}

			$title     	= isset( $instance['title'] ) ? ( $instance['title'] ) : esc_html__( 'Reservation', 'yummy-pro' );
			$guest     	= isset( $instance['guest'] ) ? ( $instance['guest'] ) : 03;
			$date     	= isset( $instance['date'] ) ? ( $instance['date'] ) : '';
			$time     	= isset( $instance['time'] ) ? ( $instance['time'] ) : esc_html__( '19:00', 'yummy-pro' );
			$button_text = isset( $instance['button_text'] ) ? ( $instance['button_text'] ) : esc_html__( 'Reserve Now', 'yummy-pro' );
			$button_url = isset( $instance['button_url'] ) ? ( $instance['button_url'] ) : '#';
			
			echo $args['before_widget']; ?>
			<div class="reservation-info-wrapper">
				<div class="entry-header-logo">
	            	<img src="<?php echo get_template_directory_uri().'/assets/uploads/separator-01.png'; ?>" alt="<?php esc_attr_e( 'logo','yummy-pro' ); ?>">
	            </div><!-- .entry-header-logo -->   
				<?php if ( ! empty( $title ) ) {
					echo $args['before_title'] . esc_html( $title ) . $args['after_title'];
				} 
				
				$reservation_info = array( esc_html__( 'Guests','yummy-pro' ),esc_html__( 'Date','yummy-pro' ),esc_html__( 'Time','yummy-pro' ) ); 
				$reservation_value = array( $guest, $date, $time );
				$index = 0;
				foreach( $reservation_info as $reservation ) { ?>
		            <div class="reservation-info clear">
		            	<span><?php echo esc_html( $reservation ); ?></span>
		            	<strong><?php echo esc_html( $reservation_value[ $index ] ); ?></strong>
		            </div><!-- .reservation-info -->
	            <?php $index++; } 

	            if( ! empty( $button_text ) ) { ?>
	            	<a href="<?php echo esc_url( $button_url ); ?>" class="more-link fill-black"><?php echo esc_html( $button_text ); ?></a>
	            <?php } ?>
            </div><!-- .reservation-info-wrapper -->

			<?php echo $args['after_widget']; }

		/**
		 * Outputs the options form on admin
		 *
		 * @param array $instance The widget options
		 */
		public function form( $instance ) {
			$title     	= isset( $instance['title'] ) ? ( $instance['title'] ) : esc_html__( 'Reservation', 'yummy-pro' );
			$guest     	= isset( $instance['guest'] ) ? ( $instance['guest'] ) : 3;
			$date     	= isset( $instance['date'] ) ? ( $instance['date'] ) : '';
			$time     	= isset( $instance['time'] ) ? ( $instance['time'] ) : esc_html__( '19:00', 'yummy-pro' );
			$button_text = isset( $instance['button_text'] ) ? ( $instance['button_text'] ) : esc_html__( 'Reserve Now', 'yummy-pro' );
			$button_url = isset( $instance['button_url'] ) ? ( $instance['button_url'] ) : '#';
		   	?>

		   	<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title:', 'yummy-pro' ); ?></label>
			    <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
		   	</p>

		   	<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'guest' ) ); ?>"><?php esc_html_e( 'Guest:', 'yummy-pro' ); ?></label>
			    <input class="tiny-text" id="<?php echo esc_attr( $this->get_field_id( 'guest' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'guest' ) ); ?>" type="number" step="1" min="2" max="100" value="<?php echo absint( $guest ); ?>" size="3" />
		   	</p>

		   	<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'date' ) ); ?>"><?php esc_html_e( 'Date:', 'yummy-pro' ); ?></label>
			    <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'date' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'date' ) ); ?>" type="date" value="<?php echo esc_attr( $date ); ?>" />
		   	</p>

		   	<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'time' ) ); ?>"><?php esc_html_e( 'Time:', 'yummy-pro' ); ?></label>
			    <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'time' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'time' ) ); ?>" type="time" value="<?php echo esc_attr( $time ); ?>" />
		   	</p>

		   	<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'button_text' ) ); ?>"><?php esc_html_e( 'Text For Button:', 'yummy-pro' ); ?></label>
			    <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'button_text' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'button_text' ) ); ?>" type="text" value="<?php echo esc_attr( $button_text ); ?>" />
		   	</p>
		   	<?php if( ! empty( $button_text ) ) : ?>
		   	<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'button_url' ) ); ?>"><?php esc_html_e( 'Url For Button:', 'yummy-pro' ); ?></label>
			    <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'button_url' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'button_url' ) ); ?>" type="text" value="<?php echo esc_url( $button_url ); ?>" />
		   	</p>
		<?php endif; }

		/**
		* Processing widget options on save
		*
		* @param array $new_instance The new options
		* @param array $old_instance The previous options
		*/
		public function update( $new_instance, $old_instance ) {
			// processes widget options to be saved
			$instance           			= $old_instance;
			$instance['title']  			= sanitize_text_field( $new_instance['title'] );
			$instance['guest']  			= absint( $new_instance['guest'] );
			$instance['date']  				= sanitize_text_field( $new_instance['date'] );
			$instance['time']  				= sanitize_text_field( $new_instance['time'] );
			$instance['button_text']  		= sanitize_text_field( $new_instance['button_text'] );
			$instance['button_url']  		= esc_url_raw( $new_instance['button_url'] );
			return $instance;
		}
	}
endif;

function yummy_pro_register_reservation_widget() {
	register_widget( 'Yummy_Pro_Custom_Reservation_Widget' );
}
add_action( 'widgets_init', 'yummy_pro_register_reservation_widget' );