<?php
/**
 * WooCommerce Hooks
 *
 * @package Theme Palace
 * @subpackage Yummy pro
 * @since Yummy Pro 1.0
 */

/**
 * Make theme WooCommerce ready
 */

remove_action( 'woocommerce_before_shop_loop', 'woocommerce_result_count', 20);
remove_action( 'woocommerce_before_main_content', 'woocommerce_output_content_wrapper', 10);
remove_action( 'woocommerce_after_main_content', 'woocommerce_output_content_wrapper_end', 10);
remove_action( 'woocommerce_before_main_content','woocommerce_breadcrumb', 20 );
remove_action( 'woocommerce_sidebar', 'woocommerce_get_sidebar', 10 );
remove_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_add_to_cart', 10 );
remove_action( 'woocommerce_after_shop_loop_item_title', 'woocommerce_template_loop_rating', 5 );
remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_rating', 10 );
remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_meta', 40 );

add_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_rating', 20 );
add_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_meta', 20 );
add_action( 'yummy_pro_add_to_cart', 'woocommerce_template_loop_add_to_cart', 10 );
add_action( 'yummy_pro_star_rating', 'woocommerce_template_loop_rating', 10 );


add_action('woocommerce_archive_description', 'yummy_pro_primary_content_start', 20);
if ( ! function_exists( 'yummy_pro_primary_content_start' ) ) :
	/**
	 * Shop Page Sale Section
	 *
	 * @since Yummy Pro 1.0
	 *
	 */
	function yummy_pro_primary_content_start() { 
		remove_action( 'pre_get_posts', 'yummy_pro_filter_get_posts' );
		$options = yummy_pro_get_theme_options();
		$args = array(
		    'posts_per_page'    => -1,
		    'no_found_rows'     => 1,
		    'post_status'       => 'publish',
		    'post_type'         => 'product',
		    'orderby'			=> 'date',
		    'order'				=> 'DESC',
		    'meta_query'        => WC()->query->get_meta_query(),
		    'post__in'          => array_merge( array( 0 ), wc_get_product_ids_on_sale() )
		);
		$woo_posts = get_posts( $args );

		if ( empty( $woo_posts ) ) {
			return ;
		} 

		$product_term = array();
		$i = 1;
		foreach ( $woo_posts as $post ) :
			$terms = get_the_terms( $post->ID, 'product_cat' );
			$terms = ! empty( $terms ) ? $terms : array();

			foreach ( $terms as $term ) :
				if ( ! in_array( $term->slug, array_column( $product_term, 'slug' ) ) ) :

					$thumbnail_id = get_woocommerce_term_meta( $term->term_id, 'thumbnail_id', true );
	    			$image = wp_get_attachment_url( $thumbnail_id );

					$product_term[$i]['name'] 		= $term->name;
					$product_term[$i]['slug'] 		= $term->slug;
					$product_term[$i]['img_url'] 	= ! empty( $image ) ? $image : get_template_directory_uri() . '/assets/uploads/restaurant.png';
				endif;
				$i ++;
			endforeach;
		endforeach; 

		if ( empty( $product_term ) ) {
			return ;
		}		
		?>
		<section id="shop-category" class="col-2">
			<div class="wrapper">
				<div class="special-offer" style="background-image:url('<?php echo get_template_directory_uri(); ?>/assets/uploads/special-offer.png')">
					<div class="overlay"></div>
					<?php if( ! empty( $options['sale_title'] ) || ! empty( $options['sale_sub_title'] ) ) : ?>
						<div class="offer-content">
							<?php if ( ! empty( $options['sale_title'] ) ) : ?>
								<span class="price"><?php echo esc_html( $options['sale_title'] ); ?></span>
							<?php endif;
							if ( ! empty( $options['sale_sub_title'] ) ) :  ?>
								<h3 class="color-white"><?php echo esc_html( $options['sale_sub_title'] ); ?></h3>
							<?php endif; ?>
						</div><!--.offer-content-->
					<?php endif; ?>
				</div><!--.special-offer-->
			</div><!-- .wrapper -->
			<div class="wrapper">
				<div class="column-wrapper">
					<div class="cart-collection">
						<div class="cart-images clear">
							<ul>
								<?php foreach ( $product_term as $term ) : ?>
									<li class="shop-sale-cat">
										<a href="#" data-slug="<?php echo esc_attr( $term['slug'] ); ?>">
											<?php if ( ! empty( $term['img_url'] ) ) : ?>
												<img src="<?php echo esc_url( $term['img_url'] ); ?>" alt="<?php echo esc_attr( $term['name'] ); ?>">
											<?php endif; 
											echo esc_html( $term['name'] ); ?>
										</a>
									</li>
								<?php endforeach; ?>
							</ul>
						</div><!--.cart-images-->
					</div><!--.cart-collection-->
				</div><!--.column-wrapper-->

				<div class="column-wrapper">
					<div id="shop-sale-slide">
						<div class="shop-slider" data-slick='{"slidesToShow": 2, "slidesToScroll": 1, "infinite": false, "speed": 600, "dots": false, "arrows":false, "autoplay": true, "fade": false, "dragable":false,}'>
							<?php foreach ( $woo_posts as $post ) : 
								$post_id = $post->ID;
								if ( has_post_thumbnail( $post_id ) ) {
									$img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $post_id ), 'shop_single' );
								} else {
									$img_array[0] = get_template_directory_uri() . '/assets/uploads/no-featured-image-600x600.jpg';
								}
								$post_term = get_the_terms( $post_id, 'product_cat' );
								?>
								<div class="slider-item 
								<?php foreach ( $post_term as $term ) :
									echo esc_attr( $term->slug ) . ' '; 
								endforeach; ?>">
									<div class="featured-product-image" style="background-image:url('<?php echo esc_url( $img_array[0] ); ?>')">
										<div class="shop-details">
											<div class="pull-left">
												<h5 class="color-white"><a href="<?php the_permalink( $post_id ) ?>"><?php echo esc_html( $post->post_title ); ?></a></h5>
												<div class="pull-left meta-links">
													<?php $tags = get_the_terms( $post_id, 'product_tag' ); 
													if ( ! empty( $tags ) ) :
														foreach ( $tags as $tag ) : ?>
															<span><a href="<?php echo esc_url( get_term_link( $tag->term_id ) ); ?>"><?php echo esc_html( $tag->name ); ?></a></span>
														<?php endforeach;
													endif; ?>
												</div><!-- .meta-links -->
											</div><!-- .pull-left -->

											<div class="pull-right">
												<span class="price">
													<?php  
			                                            $product = new WC_Product( $post_id );
			                                            echo $product->get_price_html();
		                                            ?>
												</span><!-- .price -->
											</div><!--.pull-right-->
										</div><!-- .shop-details -->
									</div><!-- .featured-product-image -->
								</div><!-- .slider-item -->
							<?php endforeach; ?>
						</div><!--.shop-slider-->
					</div><!-- .tab-pane -->
				</div>
			</div>
			<div class="page-decoration">
				<img src="<?php echo get_template_directory_uri(); ?>/assets/uploads/dish-01.png" alt="<?php esc_attr_e( 'Decoration', 'yummy-pro' ); ?>">
				<img src="<?php echo get_template_directory_uri(); ?>/assets/uploads/dish-02.png" alt="<?php esc_attr_e( 'Decoration', 'yummy-pro' ); ?>">
        	</div><!-- .page-decoration -->
		</section>
	<?php }
endif;

// Change number or products per row to 3
add_filter('loop_shop_columns', 'yummy_pro_loop_columns');
if ( ! function_exists('yummy_pro_loop_columns')) {
	/**
	 * Shop Page no. of column
	 *
	 * @since Yummy Pro 1.0
	 *
	 */
	function yummy_pro_loop_columns() {
		return 3; // 3 products per row
	}
}

add_action('woocommerce_before_shop_loop', 'yummy_pro_before_product_start', 10);
if ( ! function_exists('yummy_pro_before_product_start')) {
	/**
	 * Shop Page product start
	 *
	 * @since Yummy Pro 1.0
	 *
	 */
	function yummy_pro_before_product_start() {
		echo '<section id="shop-products" class="page-section">
        	<div class="wrapper">';
	}
}

add_action('woocommerce_after_main_content', 'yummy_pro_before_product_end', 10);
if ( ! function_exists('yummy_pro_before_product_end')) {
	/**
	 * Shop Page product end
	 *
	 * @since Yummy Pro 1.0
	 *
	 */
	function yummy_pro_before_product_end() {
		$options = yummy_pro_get_theme_options();
		echo '</div><!-- end .wrapper --><div class="page-decoration">
				<img src="'. get_template_directory_uri() .'/assets/uploads/dish-03.png" alt="'. esc_attr__( 'Decoration', 'yummy-pro' ) .'">
        		<img src="'. get_template_directory_uri() .'/assets/uploads/dish-04.png" alt="'. esc_attr__( 'Decoration', 'yummy-pro' ) .'">
        		</div><!-- .page-decoration -->
        	</section><!-- end #shop-product -->';
    	if ( ! is_singular() && $options['shop_pagination_type'] == 'infinite-scroll' ) {
        	echo'<i class="fa fa-spinner fa-spin woo-loader"></i>';
        }	
	}
}


add_filter( 'woocommerce_show_page_title', 'yummy_pro_remove_page_title' );
if ( ! function_exists('yummy_pro_remove_page_title')) {
	/**
	 * Shop Page product start
	 *
	 * @since Yummy Pro 1.0
	 *
	 */
	function yummy_pro_remove_page_title() {
		return false;
	}
}

add_filter( 'woocommerce_product_add_to_cart_text', 'yummy_pro_add_to_cart_btn' );
if ( ! function_exists('yummy_pro_add_to_cart_btn')) {
	/**
	 * add to cart button
	 *
	 * @since Yummy Pro 1.0
	 *
	 */
	function yummy_pro_add_to_cart_btn() {
		return '';
	}
}

add_action( 'woocommerce_before_shop_loop', 'yummy_pro_product_category_list', 11 );
if ( ! function_exists('yummy_pro_product_category_list')) {
	/**
	 * product category lists
	 *
	 * @since Yummy Pro 1.0
	 *
	 */
	function yummy_pro_product_category_list() {
		$terms = get_terms( array(
		    'taxonomy' 	 => 'product_cat',
		    'hide_empty' => false,
		    'childless'	 => true,
		) ); 
		$product_category = get_query_var( 'term' );
		$shop_page = get_option( 'woocommerce_shop_page_id' ); 
		$shop_page = ! empty( $shop_page ) ? $shop_page : '#';
		?>
		<ul class="shop-tab clear">
            <li class="<?php echo ( $product_category == '' ) ? 'active' : ''; ?>"><a href="<?php the_permalink( $shop_page ); ?>"><?php esc_html_e( 'All', 'yummy-pro' ); ?></a></li>
            <?php foreach ( $terms as $term ) : ?>
            	<li class="<?php echo ( $product_category == $term->slug ) ? 'active' : ''; ?>" ><a href="<?php echo esc_url( get_term_link( $term->term_id ), 'product_cat' ); ?>"><?php echo esc_html( $term->name ); ?></a></li>
            <?php endforeach; ?>
      	</ul><!-- .nav-tabs -->
  	<?php
	}
}

add_action( 'woocommerce_before_single_product', 'yummy_pro_single_product_start', 5 );
if ( ! function_exists('yummy_pro_single_product_start') ) {
	/**
	 * add to cart button
	 *
	 * @since Yummy Pro 1.0
	 *
	 */
	function yummy_pro_single_product_start() {
		echo '<div class="wrapper page-section">
		<section id="product-detail" class="col-2">';
	}
}

add_action( 'woocommerce_after_single_product', 'yummy_pro_single_product_end', 20 );
if ( ! function_exists('yummy_pro_single_product_end') ) {
	/**
	 * add to cart button
	 *
	 * @since Yummy Pro 1.0
	 *
	 */
	function yummy_pro_single_product_end() {
		echo '</section><div class="page-decoration">
        	<img src="'. get_template_directory_uri() .'/assets/uploads/dish-01.png" alt="'. esc_attr__( 'Decoration', 'yummy-pro' ) .'">
        	<img src="'. get_template_directory_uri() .'/assets/uploads/dish-02.png" alt="'. esc_attr__( 'Decoration', 'yummy-pro' ) .'">
        	<img src="'. get_template_directory_uri() .'/assets/uploads/dish-03.png" alt="'. esc_attr__( 'Decoration', 'yummy-pro' ) .'">
        	<img src="'. get_template_directory_uri() .'/assets/uploads/dish-04.png" alt="'. esc_attr__( 'Decoration', 'yummy-pro' ) .'">
        </div><!-- .page-decoration --></div>';
	}
}

add_action( 'woocommerce_before_single_product_summary', 'yummy_pro_single_product_img_start', 5 );
if ( ! function_exists('yummy_pro_single_product_img_start') ) {
	/**
	 * add to cart button
	 *
	 * @since Yummy Pro 1.0
	 *
	 */
	function yummy_pro_single_product_img_start() { 
		$shop_page = get_option( 'woocommerce_shop_page_id' ); 
		$shop_page = ! empty( $shop_page ) ? $shop_page : '#';
		?>
		<div class="shop-cart clear">
			<div class="half-gray"></div>

			<div class="entry-container">
				<div class="column-wrapper">
					<div class="product-thumbnail">
						<h4 class="return-to-shop"><a href="<?php the_permalink( $shop_page ); ?>"><i class="fa fa-reply"></i><?php esc_html_e( 'Return to shop', 'yummy-pro' ); ?></a></h4>
		<?php
	}
}

add_action( 'woocommerce_before_single_product_summary', 'yummy_pro_single_product_img_end', 30 );
if ( ! function_exists('yummy_pro_single_product_img_end') ) {
	/**
	 * add to cart button
	 *
	 * @since Yummy Pro 1.0
	 *
	 */
	function yummy_pro_single_product_img_end() { ?>
			</div><!--.product-thumbnail-->
      	</div><!--.column-wrapper-->
      	<div class="column-wrapper">
	<?php
	}
}

add_action( 'woocommerce_after_single_product_summary', 'yummy_pro_single_produt_summary_end', 5 );
if ( ! function_exists('yummy_pro_single_produt_summary_end') ) {
	/**
	 * add to cart button
	 *
	 * @since Yummy Pro 1.0
	 *
	 */
	function yummy_pro_single_produt_summary_end() { ?>
      		</div><!--.column-wrapper-->
      		</div><!-- .entry-container -->
      	</div><!--.shop-cart -->
	<?php
	}
}

add_action( 'woocommerce_single_product_summary', 'yummy_pro_title_seperator', 5 );
if ( ! function_exists('yummy_pro_title_seperator') ) {
	/**
	 * Seperator after title
	 *
	 * @since Yummy Pro 1.0
	 *
	 */
	function yummy_pro_title_seperator() { ?>
      	<div class="separator"></div>
	<?php
	}
}

add_filter( 'woocommerce_output_related_products_args', 'yummy_pro_related_products_limit' );
if ( ! function_exists('yummy_pro_related_products_limit') ) {
	/**
	 * No. of related products
	 *
	 * @since Yummy Pro 1.0
	 *
	 */
	function yummy_pro_related_products_limit( $args ) { 
		global $product;

		$args['posts_per_page'] = 3;
		return $args;
	}
}
